# BMusic

Utilities for procedural music animation in Blender.

[Example](https://www.youtube.com/watch?v=ZE92NEA41nw)

![](https://github.com/phuang1024/bmusic/blob/master/examples/Debussy_ClairDeLune/example.jpg?raw=true)
